@@ -911,19 +911,11 @@ panel.violin <-
 }
 
 
-
 ### dotplot, barchart and stripplot: essentially wrappers to bwplot
 
 
 dotplot <- function(x, data, ...) UseMethod("dotplot")
 
-dotplot.data.frame <- function(x, data = NULL, formula = data, ...)
-{
-    ocall <- sys.call(); ocall[[1]] <- quote(dotplot)
-    if (!inherits(formula, "formula")) stop("'formula' must be a formula object")
-    modifyList(dotplot(formula, x, ...), list(call = ocall))
-}
-
 ## dotplot.numeric <-
 ##     function(formula, data = NULL, xlab = deparse(substitute(formula)), ...)
 ## {
@@ -1034,13 +1026,6 @@ dotplot.formula <-
 
 barchart <- function(x, data, ...) UseMethod("barchart")
 
-barchart.data.frame <- function(x, data = NULL, formula = data, ...)
-{
-    ocall <- sys.call(); ocall[[1]] <- quote(barchart)
-    if (!inherits(formula, "formula")) stop("'formula' must be a formula object")
-    modifyList(barchart(formula, x, ...), list(call = ocall))
-}
-
 barchart.numeric <-
     function(x, data = NULL, xlab = deparse(substitute(x)), ...)
 {
@@ -1058,8 +1043,6 @@ barchart.numeric <-
 }
 
 
-
-
 barchart.table <-
     function(x, data = NULL, groups = TRUE,
              origin = 0, stack = TRUE, ..., horizontal = TRUE)
@@ -1135,13 +1118,6 @@ barchart.formula <-
 
 stripplot <- function(x, data, ...)  UseMethod("stripplot")
 
-stripplot.data.frame <- function(x, data = NULL, formula = data, ...)
-{
-    ocall <- sys.call(); ocall[[1]] <- quote(stripplot)
-    if (!inherits(formula, "formula")) stop("'formula' must be a formula object")
-    modifyList(stripplot(formula, x, ...), list(call = ocall))
-}
-
 stripplot.numeric <-
     function(x, data = NULL, xlab = deparse(substitute(x)), ...)
 {
@@ -1185,14 +1161,6 @@ stripplot.formula <-
 
 bwplot <- function(x, data, ...) UseMethod("bwplot")
 
-bwplot.data.frame <- function(x, data = NULL, formula = data, ...)
-{
-    ocall <- sys.call(); ocall[[1]] <- quote(bwplot)
-    if (!inherits(formula, "formula")) stop("'formula' must be a formula object")
-    modifyList(bwplot(formula, x, ...), list(call = ocall))
-}
-
-
 
 bwplot.numeric <-
     function(x, data = NULL, xlab = deparse(substitute(x)), ...)
